==> james-project-3.7.6-source-release.zip: james-project/server/container/guice/testing/custom-mailets/src/main/java/com/custom/mailets/AnotherMailet.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package com.custom.mailets;

import javax.mail.MessagingException;

import org.apache.mailet.ExcludeFromDocumentation;
import org.apache.mailet.Mail;
import org.apache.mailet.base.GenericMailet;

/**
 * Mailet introduced for testing purposes.
 *
 * Does nothing.
 */

@ExcludeFromDocumentation
public class AnotherMailet extends GenericMailet {

    @Override
    public void service(Mail mail) throws MessagingException {

    }
}

==> james-project-3.9.0-source-release.zip: james-project/server/container/guice/testing/custom-mailets/src/main/java/com/custom/mailets/AnotherMailet.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package com.custom.mailets;

import jakarta.mail.MessagingException;

import org.apache.mailet.ExcludeFromDocumentation;
import org.apache.mailet.Mail;
import org.apache.mailet.base.GenericMailet;

/**
 * Mailet introduced for testing purposes.
 *
 * Does nothing.
 */

@ExcludeFromDocumentation
public class AnotherMailet extends GenericMailet {

    @Override
    public void service(Mail mail) throws MessagingException {

    }
}
